# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: starknet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x0estarknet.proto\x12\x19\x61pibara.starknet.v1alpha2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0btypes.proto\"\xa2\x03\n\x05\x42lock\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.apibara.starknet.v1alpha2.BlockStatus\x12\x36\n\x06header\x18\x02 \x01(\x0b\x32&.apibara.starknet.v1alpha2.BlockHeader\x12G\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x31.apibara.starknet.v1alpha2.TransactionWithReceipt\x12<\n\x0cstate_update\x18\x04 \x01(\x0b\x32&.apibara.starknet.v1alpha2.StateUpdate\x12?\n\x06\x65vents\x18\x05 \x03(\x0b\x32/.apibara.starknet.v1alpha2.EventWithTransaction\x12R\n\x11l2_to_l1_messages\x18\x06 \x03(\x0b\x32\x37.apibara.starknet.v1alpha2.L2ToL1MessageWithTransaction\x12\r\n\x05\x65mpty\x18\x07 \x01(\x08\"\xc7\x04\n\x0b\x42lockHeader\x12;\n\nblock_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x42\n\x11parent_block_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x14\n\x0c\x62lock_number\x18\x03 \x01(\x04\x12\x42\n\x11sequencer_address\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08new_root\x18\x05 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10starknet_version\x18\x07 \x01(\t\x12>\n\x0cl1_gas_price\x18\x08 \x01(\x0b\x32(.apibara.starknet.v1alpha2.ResourcePrice\x12\x43\n\x11l1_data_gas_price\x18\t \x01(\x0b\x32(.apibara.starknet.v1alpha2.ResourcePrice\x12T\n\x19l1_data_availability_mode\x18\n \x01(\x0e\x32\x31.apibara.starknet.v1alpha2.L1DataAvailabilityMode\"\x95\x01\n\x16TransactionWithReceipt\x12;\n\x0btransaction\x18\x01 \x01(\x0b\x32&.apibara.starknet.v1alpha2.Transaction\x12>\n\x07receipt\x18\x02 \x01(\x0b\x32-.apibara.starknet.v1alpha2.TransactionReceipt\"\xd8\x05\n\x0bTransaction\x12\x38\n\x04meta\x18\x01 \x01(\x0b\x32*.apibara.starknet.v1alpha2.TransactionMeta\x12\x43\n\tinvoke_v0\x18\x02 \x01(\x0b\x32..apibara.starknet.v1alpha2.InvokeTransactionV0H\x00\x12\x43\n\tinvoke_v1\x18\x03 \x01(\x0b\x32..apibara.starknet.v1alpha2.InvokeTransactionV1H\x00\x12>\n\x06\x64\x65ploy\x18\x04 \x01(\x0b\x32,.apibara.starknet.v1alpha2.DeployTransactionH\x00\x12@\n\x07\x64\x65\x63lare\x18\x05 \x01(\x0b\x32-.apibara.starknet.v1alpha2.DeclareTransactionH\x00\x12\x45\n\nl1_handler\x18\x06 \x01(\x0b\x32/.apibara.starknet.v1alpha2.L1HandlerTransactionH\x00\x12M\n\x0e\x64\x65ploy_account\x18\x07 \x01(\x0b\x32\x33.apibara.starknet.v1alpha2.DeployAccountTransactionH\x00\x12R\n\x11\x64\x65ploy_account_v3\x18\x08 \x01(\x0b\x32\x35.apibara.starknet.v1alpha2.DeployAccountTransactionV3H\x00\x12\x43\n\tinvoke_v3\x18\t \x01(\x0b\x32..apibara.starknet.v1alpha2.InvokeTransactionV3H\x00\x12\x45\n\ndeclare_v3\x18\n \x01(\x0b\x32/.apibara.starknet.v1alpha2.DeclareTransactionV3H\x00\x42\r\n\x0btransaction\"\xe7\x04\n\x0fTransactionMeta\x12\x35\n\x04hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x38\n\x07max_fee\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12:\n\tsignature\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x36\n\x05nonce\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x0f\n\x07version\x18\x05 \x01(\x04\x12I\n\x0fresource_bounds\x18\x06 \x01(\x0b\x32\x30.apibara.starknet.v1alpha2.ResourceBoundsMapping\x12\x0b\n\x03tip\x18\x07 \x01(\x04\x12?\n\x0epaymaster_data\x18\x08 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12U\n\x1cnonce_data_availability_mode\x18\t \x01(\x0e\x32/.apibara.starknet.v1alpha2.DataAvailabilityMode\x12S\n\x1a\x66\x65\x65_data_availability_mode\x18\n \x01(\x0e\x32/.apibara.starknet.v1alpha2.DataAvailabilityMode\x12\x19\n\x11transaction_index\x18\x0b \x01(\x04\"\xda\x01\n\x13InvokeTransactionV0\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x45\n\x14\x65ntry_point_selector\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x91\x01\n\x13InvokeTransactionV1\x12?\n\x0esender_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xdb\x01\n\x13InvokeTransactionV3\x12?\n\x0esender_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12H\n\x17\x61\x63\x63ount_deployment_data\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xdf\x01\n\x11\x44\x65ployTransaction\x12\x45\n\x14\x63onstructor_calldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x46\n\x15\x63ontract_address_salt\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xd8\x01\n\x12\x44\x65\x63lareTransaction\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12?\n\x0esender_address\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x13\x63ompiled_class_hash\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xa4\x02\n\x14\x44\x65\x63lareTransactionV3\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12?\n\x0esender_address\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x13\x63ompiled_class_hash\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12H\n\x17\x61\x63\x63ount_deployment_data\x18\x04 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xdb\x01\n\x14L1HandlerTransaction\x12\x41\n\x10\x63ontract_address\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x45\n\x14\x65ntry_point_selector\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x04 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xe6\x01\n\x18\x44\x65ployAccountTransaction\x12\x45\n\x14\x63onstructor_calldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x46\n\x15\x63ontract_address_salt\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xe8\x01\n\x1a\x44\x65ployAccountTransactionV3\x12\x45\n\x14\x63onstructor_calldata\x18\x01 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x46\n\x15\x63ontract_address_salt\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xd2\x04\n\x12TransactionReceipt\x12\x41\n\x10transaction_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x19\n\x11transaction_index\x18\x02 \x01(\x04\x12;\n\nactual_fee\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x43\n\x11l2_to_l1_messages\x18\x04 \x03(\x0b\x32(.apibara.starknet.v1alpha2.L2ToL1Message\x12\x30\n\x06\x65vents\x18\x05 \x03(\x0b\x32 .apibara.starknet.v1alpha2.Event\x12\x41\n\x10\x63ontract_address\x18\x06 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x10\x65xecution_status\x18\x07 \x01(\x0e\x32*.apibara.starknet.v1alpha2.ExecutionStatus\x12\x15\n\rrevert_reason\x18\x08 \x01(\t\x12>\n\x0f\x61\x63tual_fee_paid\x18\t \x01(\x0b\x32%.apibara.starknet.v1alpha2.FeePayment\x12J\n\x13\x65xecution_resources\x18\n \x01(\x0b\x32-.apibara.starknet.v1alpha2.ExecutionResources\"\xd6\x01\n\x1cL2ToL1MessageWithTransaction\x12;\n\x0btransaction\x18\x01 \x01(\x0b\x32&.apibara.starknet.v1alpha2.Transaction\x12>\n\x07receipt\x18\x02 \x01(\x0b\x32-.apibara.starknet.v1alpha2.TransactionReceipt\x12\x39\n\x07message\x18\x03 \x01(\x0b\x32(.apibara.starknet.v1alpha2.L2ToL1Message\"\xd4\x01\n\rL2ToL1Message\x12;\n\nto_address\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x38\n\x07payload\x18\x04 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\r\n\x05index\x18\x05 \x01(\x04\x12=\n\x0c\x66rom_address\x18\x06 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xc4\x01\n\x14\x45ventWithTransaction\x12;\n\x0btransaction\x18\x01 \x01(\x0b\x32&.apibara.starknet.v1alpha2.Transaction\x12>\n\x07receipt\x18\x02 \x01(\x0b\x32-.apibara.starknet.v1alpha2.TransactionReceipt\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32 .apibara.starknet.v1alpha2.Event\"\xc3\x01\n\x05\x45vent\x12=\n\x0c\x66rom_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x35\n\x04keys\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x35\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\r\n\x05index\x18\x04 \x01(\x04\"\xbd\x01\n\x0bStateUpdate\x12\x39\n\x08new_root\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08old_root\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x38\n\nstate_diff\x18\x03 \x01(\x0b\x32$.apibara.starknet.v1alpha2.StateDiff\"\x9c\x03\n\tStateDiff\x12=\n\rstorage_diffs\x18\x01 \x03(\x0b\x32&.apibara.starknet.v1alpha2.StorageDiff\x12G\n\x12\x64\x65\x63lared_contracts\x18\x02 \x03(\x0b\x32+.apibara.starknet.v1alpha2.DeclaredContract\x12G\n\x12\x64\x65ployed_contracts\x18\x03 \x03(\x0b\x32+.apibara.starknet.v1alpha2.DeployedContract\x12\x36\n\x06nonces\x18\x04 \x03(\x0b\x32&.apibara.starknet.v1alpha2.NonceUpdate\x12\x42\n\x10\x64\x65\x63lared_classes\x18\x05 \x03(\x0b\x32(.apibara.starknet.v1alpha2.DeclaredClass\x12\x42\n\x10replaced_classes\x18\x06 \x03(\x0b\x32(.apibara.starknet.v1alpha2.ReplacedClass\"\x92\x01\n\x0bStorageDiff\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12@\n\x0fstorage_entries\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.StorageEntry\"|\n\x0cStorageEntry\x12\x34\n\x03key\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"O\n\x10\x44\x65\x63laredContract\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x92\x01\n\rDeclaredClass\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x13\x63ompiled_class_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x8f\x01\n\rReplacedClass\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x92\x01\n\x10\x44\x65ployedContract\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x88\x01\n\x0bNonceUpdate\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x36\n\x05nonce\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x8d\x01\n\rResourcePrice\x12=\n\x0cprice_in_fri\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12=\n\x0cprice_in_wei\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"y\n\nFeePayment\x12\x37\n\x06\x61mount\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x32\n\x04unit\x18\x02 \x01(\x0e\x32$.apibara.starknet.v1alpha2.PriceUnit\"\xab\x01\n\x12\x45xecutionResources\x12\x44\n\x0b\x63omputation\x18\x01 \x01(\x0b\x32/.apibara.starknet.v1alpha2.ComputationResources\x12O\n\x11\x64\x61ta_availability\x18\x02 \x01(\x0b\x32\x34.apibara.starknet.v1alpha2.DataAvailabilityResources\"\xe5\x02\n\x14\x43omputationResources\x12\r\n\x05steps\x18\x01 \x01(\x04\x12\x14\n\x0cmemory_holes\x18\x02 \x01(\x04\x12(\n range_check_builtin_applications\x18\x03 \x01(\x04\x12%\n\x1dpedersen_builtin_applications\x18\x04 \x01(\x04\x12%\n\x1dposeidon_builtin_applications\x18\x05 \x01(\x04\x12\"\n\x1a\x65\x63_op_builtin_applications\x18\x06 \x01(\x04\x12\"\n\x1a\x65\x63\x64sa_builtin_applications\x18\x07 \x01(\x04\x12$\n\x1c\x62itwise_builtin_applications\x18\x08 \x01(\x04\x12#\n\x1bkeccak_builtin_applications\x18\t \x01(\x04\x12\x1d\n\x15segment_arena_builtin\x18\n \x01(\x04\"@\n\x19\x44\x61taAvailabilityResources\x12\x0e\n\x06l1_gas\x18\x01 \x01(\x04\x12\x13\n\x0bl1_data_gas\x18\x02 \x01(\x04\"\x8d\x01\n\x15ResourceBoundsMapping\x12\x39\n\x06l1_gas\x18\x01 \x01(\x0b\x32).apibara.starknet.v1alpha2.ResourceBounds\x12\x39\n\x06l2_gas\x18\x02 \x01(\x0b\x32).apibara.starknet.v1alpha2.ResourceBounds\"d\n\x0eResourceBounds\x12\x12\n\nmax_amount\x18\x01 \x01(\x04\x12>\n\x12max_price_per_unit\x18\x02 \x01(\x0b\x32\".apibara.starknet.v1alpha2.Uint128\"$\n\x07Uint128\x12\x0b\n\x03low\x18\x01 \x01(\x04\x12\x0c\n\x04high\x18\x02 \x01(\x04*\x8f\x01\n\x16L1DataAvailabilityMode\x12)\n%L1_DATA_AVAILABILITY_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1eL1_DATA_AVAILABILITY_MODE_BLOB\x10\x01\x12&\n\"L1_DATA_AVAILABILITY_MODE_CALLDATA\x10\x02*\xa2\x01\n\x0b\x42lockStatus\x12\x1c\n\x18\x42LOCK_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42LOCK_STATUS_PENDING\x10\x01\x12\x1f\n\x1b\x42LOCK_STATUS_ACCEPTED_ON_L2\x10\x02\x12\x1f\n\x1b\x42LOCK_STATUS_ACCEPTED_ON_L1\x10\x03\x12\x19\n\x15\x42LOCK_STATUS_REJECTED\x10\x04*r\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x45XECUTION_STATUS_SUCCEEDED\x10\x01\x12\x1d\n\x19\x45XECUTION_STATUS_REVERTED\x10\x02*O\n\tPriceUnit\x12\x1a\n\x16PRICE_UNIT_UNSPECIFIED\x10\x00\x12\x12\n\x0ePRICE_UNIT_WEI\x10\x01\x12\x12\n\x0ePRICE_UNIT_FRI\x10\x02*|\n\x14\x44\x61taAvailabilityMode\x12&\n\"DATA_AVAILABILITY_MODE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44\x41TA_AVAILABILITY_MODE_L1\x10\x01\x12\x1d\n\x19\x44\x41TA_AVAILABILITY_MODE_L2\x10\x02\x62\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "starknet_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_L1DATAAVAILABILITYMODE"]._serialized_start = 8744
    _globals["_L1DATAAVAILABILITYMODE"]._serialized_end = 8887
    _globals["_BLOCKSTATUS"]._serialized_start = 8890
    _globals["_BLOCKSTATUS"]._serialized_end = 9052
    _globals["_EXECUTIONSTATUS"]._serialized_start = 9054
    _globals["_EXECUTIONSTATUS"]._serialized_end = 9168
    _globals["_PRICEUNIT"]._serialized_start = 9170
    _globals["_PRICEUNIT"]._serialized_end = 9249
    _globals["_DATAAVAILABILITYMODE"]._serialized_start = 9251
    _globals["_DATAAVAILABILITYMODE"]._serialized_end = 9375
    _globals["_BLOCK"]._serialized_start = 92
    _globals["_BLOCK"]._serialized_end = 510
    _globals["_BLOCKHEADER"]._serialized_start = 513
    _globals["_BLOCKHEADER"]._serialized_end = 1096
    _globals["_TRANSACTIONWITHRECEIPT"]._serialized_start = 1099
    _globals["_TRANSACTIONWITHRECEIPT"]._serialized_end = 1248
    _globals["_TRANSACTION"]._serialized_start = 1251
    _globals["_TRANSACTION"]._serialized_end = 1979
    _globals["_TRANSACTIONMETA"]._serialized_start = 1982
    _globals["_TRANSACTIONMETA"]._serialized_end = 2597
    _globals["_INVOKETRANSACTIONV0"]._serialized_start = 2600
    _globals["_INVOKETRANSACTIONV0"]._serialized_end = 2818
    _globals["_INVOKETRANSACTIONV1"]._serialized_start = 2821
    _globals["_INVOKETRANSACTIONV1"]._serialized_end = 2966
    _globals["_INVOKETRANSACTIONV3"]._serialized_start = 2969
    _globals["_INVOKETRANSACTIONV3"]._serialized_end = 3188
    _globals["_DEPLOYTRANSACTION"]._serialized_start = 3191
    _globals["_DEPLOYTRANSACTION"]._serialized_end = 3414
    _globals["_DECLARETRANSACTION"]._serialized_start = 3417
    _globals["_DECLARETRANSACTION"]._serialized_end = 3633
    _globals["_DECLARETRANSACTIONV3"]._serialized_start = 3636
    _globals["_DECLARETRANSACTIONV3"]._serialized_end = 3928
    _globals["_L1HANDLERTRANSACTION"]._serialized_start = 3931
    _globals["_L1HANDLERTRANSACTION"]._serialized_end = 4150
    _globals["_DEPLOYACCOUNTTRANSACTION"]._serialized_start = 4153
    _globals["_DEPLOYACCOUNTTRANSACTION"]._serialized_end = 4383
    _globals["_DEPLOYACCOUNTTRANSACTIONV3"]._serialized_start = 4386
    _globals["_DEPLOYACCOUNTTRANSACTIONV3"]._serialized_end = 4618
    _globals["_TRANSACTIONRECEIPT"]._serialized_start = 4621
    _globals["_TRANSACTIONRECEIPT"]._serialized_end = 5215
    _globals["_L2TOL1MESSAGEWITHTRANSACTION"]._serialized_start = 5218
    _globals["_L2TOL1MESSAGEWITHTRANSACTION"]._serialized_end = 5432
    _globals["_L2TOL1MESSAGE"]._serialized_start = 5435
    _globals["_L2TOL1MESSAGE"]._serialized_end = 5647
    _globals["_EVENTWITHTRANSACTION"]._serialized_start = 5650
    _globals["_EVENTWITHTRANSACTION"]._serialized_end = 5846
    _globals["_EVENT"]._serialized_start = 5849
    _globals["_EVENT"]._serialized_end = 6044
    _globals["_STATEUPDATE"]._serialized_start = 6047
    _globals["_STATEUPDATE"]._serialized_end = 6236
    _globals["_STATEDIFF"]._serialized_start = 6239
    _globals["_STATEDIFF"]._serialized_end = 6651
    _globals["_STORAGEDIFF"]._serialized_start = 6654
    _globals["_STORAGEDIFF"]._serialized_end = 6800
    _globals["_STORAGEENTRY"]._serialized_start = 6802
    _globals["_STORAGEENTRY"]._serialized_end = 6926
    _globals["_DECLAREDCONTRACT"]._serialized_start = 6928
    _globals["_DECLAREDCONTRACT"]._serialized_end = 7007
    _globals["_DECLAREDCLASS"]._serialized_start = 7010
    _globals["_DECLAREDCLASS"]._serialized_end = 7156
    _globals["_REPLACEDCLASS"]._serialized_start = 7159
    _globals["_REPLACEDCLASS"]._serialized_end = 7302
    _globals["_DEPLOYEDCONTRACT"]._serialized_start = 7305
    _globals["_DEPLOYEDCONTRACT"]._serialized_end = 7451
    _globals["_NONCEUPDATE"]._serialized_start = 7454
    _globals["_NONCEUPDATE"]._serialized_end = 7590
    _globals["_RESOURCEPRICE"]._serialized_start = 7593
    _globals["_RESOURCEPRICE"]._serialized_end = 7734
    _globals["_FEEPAYMENT"]._serialized_start = 7736
    _globals["_FEEPAYMENT"]._serialized_end = 7857
    _globals["_EXECUTIONRESOURCES"]._serialized_start = 7860
    _globals["_EXECUTIONRESOURCES"]._serialized_end = 8031
    _globals["_COMPUTATIONRESOURCES"]._serialized_start = 8034
    _globals["_COMPUTATIONRESOURCES"]._serialized_end = 8391
    _globals["_DATAAVAILABILITYRESOURCES"]._serialized_start = 8393
    _globals["_DATAAVAILABILITYRESOURCES"]._serialized_end = 8457
    _globals["_RESOURCEBOUNDSMAPPING"]._serialized_start = 8460
    _globals["_RESOURCEBOUNDSMAPPING"]._serialized_end = 8601
    _globals["_RESOURCEBOUNDS"]._serialized_start = 8603
    _globals["_RESOURCEBOUNDS"]._serialized_end = 8703
    _globals["_UINT128"]._serialized_start = 8705
    _globals["_UINT128"]._serialized_end = 8741
# @@protoc_insertion_point(module_scope)
